<?php
/**
 * The main Kirki object
 *
 * @package     Kirki
 * @category    Core
 * @author      Aristeides Stathopoulos
 * @copyright   Copyright (c) 2015, Aristeides Stathopoulos
 * @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
 * @since       1.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Early exit if the class already exists
if ( class_exists( 'Kirki_Toolkit' ) ) {
	return;
}

class Kirki_Toolkit {

	/** @var Kirki The only instance of this class */
	public static $instance = null;

	public static $version = '1.0.2';

	public $font_registry = null;
	public $scripts = null;
	public $api = null;
	public $styles = array();

	/**
	 * Access the single instance of this class
	 * @return Kirki
	 */
	public static function get_instance() {
		if ( null == self::$instance ) {
			self::$instance = new Kirki_Toolkit();
		}

		return self::$instance;
	}

	/**
	 * Shortcut method to get the translation strings
	 */
	public static function i18n() {

		$i18n = array(
			'background-color'      => esc_html__( 'Background Color', 'tm-builder' ),
			'background-image'      => esc_html__( 'Background Image', 'tm-builder' ),
			'no-repeat'             => esc_html__( 'No Repeat', 'tm-builder' ),
			'repeat-all'            => esc_html__( 'Repeat All', 'tm-builder' ),
			'repeat-x'              => esc_html__( 'Repeat Horizontally', 'tm-builder' ),
			'repeat-y'              => esc_html__( 'Repeat Vertically', 'tm-builder' ),
			'inherit'               => esc_html__( 'Inherit', 'tm-builder' ),
			'background-repeat'     => esc_html__( 'Background Repeat', 'tm-builder' ),
			'cover'                 => esc_html__( 'Cover', 'tm-builder' ),
			'contain'               => esc_html__( 'Contain', 'tm-builder' ),
			'background-size'       => esc_html__( 'Background Size', 'tm-builder' ),
			'fixed'                 => esc_html__( 'Fixed', 'tm-builder' ),
			'scroll'                => esc_html__( 'Scroll', 'tm-builder' ),
			'background-attachment' => esc_html__( 'Background Attachment', 'tm-builder' ),
			'left-top'              => esc_html__( 'Left Top', 'tm-builder' ),
			'left-center'           => esc_html__( 'Left Center', 'tm-builder' ),
			'left-bottom'           => esc_html__( 'Left Bottom', 'tm-builder' ),
			'right-top'             => esc_html__( 'Right Top', 'tm-builder' ),
			'right-center'          => esc_html__( 'Right Center', 'tm-builder' ),
			'right-bottom'          => esc_html__( 'Right Bottom', 'tm-builder' ),
			'center-top'            => esc_html__( 'Center Top', 'tm-builder' ),
			'center-center'         => esc_html__( 'Center Center', 'tm-builder' ),
			'center-bottom'         => esc_html__( 'Center Bottom', 'tm-builder' ),
			'background-position'   => esc_html__( 'Background Position', 'tm-builder' ),
			'background-opacity'    => esc_html__( 'Background Opacity', 'tm-builder' ),
			'ON'                    => esc_html__( 'ON', 'tm-builder' ),
			'OFF'                   => esc_html__( 'OFF', 'tm-builder' ),
			'all'                   => esc_html__( 'All', 'tm-builder' ),
			'cyrillic'              => esc_html__( 'Cyrillic', 'tm-builder' ),
			'cyrillic-ext'          => esc_html__( 'Cyrillic Extended', 'tm-builder' ),
			'devanagari'            => esc_html__( 'Devanagari', 'tm-builder' ),
			'greek'                 => esc_html__( 'Greek', 'tm-builder' ),
			'greek-ext'             => esc_html__( 'Greek Extended', 'tm-builder' ),
			'khmer'                 => esc_html__( 'Khmer', 'tm-builder' ),
			'latin'                 => esc_html__( 'Latin', 'tm-builder' ),
			'latin-ext'             => esc_html__( 'Latin Extended', 'tm-builder' ),
			'vietnamese'            => esc_html__( 'Vietnamese', 'tm-builder' ),
			'serif'                 => _x( 'Serif', 'font style', 'tm-builder' ),
			'sans-serif'            => _x( 'Sans Serif', 'font style', 'tm-builder' ),
			'monospace'             => _x( 'Monospace', 'font style', 'tm-builder' ),
		);

		$config = apply_filters( 'kirki/config', array() );

		if ( isset( $config['i18n'] ) ) {
			$i18n = wp_parse_args( $config['i18n'], $i18n );
		}

		return $i18n;

	}

	/**
	 * Shortcut method to get the font registry.
	 */
	public static function fonts() {
		return self::get_instance()->font_registry;
	}

	/**
	 * Constructor is private, should only be called by get_instance()
	 */
	private function __construct() {
	}

}
