<?php
/**
 * Infinity functions and definitions
 *
 * @package Infinity
 */

if ( ! function_exists( 'infinity_setup' ) ) : /**
 * Sets up theme defaults and registers support for various WordPress features.
 * ===========================================================================
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */ {
	function infinity_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Infinity, use a find and replace
		 * to change 'tm-builder' to the name of your theme in all the template files
		 */
		load_theme_textdomain( 'tm-builder', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'post-thumb', 848, 450, true );
		add_image_size( 'small-thumb', 120, 90, true );
		add_image_size( 'medium-thumb', 370, 220, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'tm-builder' ),
			'social'  => esc_html__( 'Social Profile Menu', 'tm-builder' ),
			'top'     => esc_html__( 'Top Menu', 'tm-builder' )
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );

		/*
		 * Enable support for Post Formats.
		 * See http://codex.wordpress.org/Post_Formats
		 */
		add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'infinity_custom_background_args', array(
			'default-color' => '#ffffff',
			'default-image' => '',
		) ) );

		// Support woocommerce
		add_theme_support( 'woocommerce' );
	}
}
endif; // infinity_setup
add_action( 'after_setup_theme', 'infinity_setup' );

/**
 * Define Constants
 * ================
 */
define( 'TM_BUILDER_THEME_ROOT', esc_url( get_template_directory_uri() ) );
define( 'TM_BUILDER_PARENT_THEME_NAME', wp_get_theme( 'tm-builder' )->get( 'Name' ) );
define( 'TM_BUILDER_PARENT_THEME_VERSION', wp_get_theme( 'tm-builder' )->get( 'Version' ) );
define( 'TM_BUILDER_PARENT_THEME_AUTHOR', wp_get_theme( 'tm-builder' )->get( 'Author' ) );
define( 'TM_BUILDER_PRIMARY_COLOR', '#003164' );
define( 'TM_BUILDER_SECONDARY_COLOR', '#868686' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 * ===========================================================================
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

/**
 * Register widget area.
 * ====================
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function infinity_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'tm-builder' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Top Slider', 'tm-builder' ),
		'id'            => 'top-slider',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Header Right', 'tm-builder' ),
		'id'            => 'header-right',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget header-right %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	if ( class_exists( 'WooCommerce' ) ) {
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar for Shop', 'tm-builder' ),
			'id'            => 'sidebar-shop',
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
		register_sidebar( array(
			'name'          => esc_html__( 'Top of Shop page', 'tm-builder' ),
			'id'            => 'top-shop',
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	}
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1 Widget Area', 'tm-builder' ),
		'id'            => 'footer',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2 Widget Area', 'tm-builder' ),
		'id'            => 'footer2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3 Widget Area', 'tm-builder' ),
		'id'            => 'footer3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title"><span>',
		'after_title'   => '</span></h3>',
	) );
}

add_action( 'widgets_init', 'infinity_widgets_init' );

/**
 * Enqueue scripts and styles.
 * ==========================
 */
function infinity_scripts() {
	wp_enqueue_style( 'infinity-style', TM_BUILDER_THEME_ROOT . '/style.css' );
	wp_enqueue_style( 'infinity-main', TM_BUILDER_THEME_ROOT . '/css/main.css' );
	wp_enqueue_style( 'infinity-font-awesome', TM_BUILDER_THEME_ROOT . '/css/font-awesome.min.css' );
	wp_enqueue_style( 'infinity-prettyphoto', TM_BUILDER_THEME_ROOT . '/css/prettyPhoto.css' );

	if ( Kirki::get_option( 'tm-builder', 'nav_sticky_enable' ) == 1 ) {
		wp_enqueue_script( 'infinity-js-head-room-jquery', TM_BUILDER_THEME_ROOT . '/js/jQuery.headroom.min.js', array( 'jquery' ), TM_BUILDER_PARENT_THEME_VERSION, true );
		wp_enqueue_script( 'infinity-js-head-room', TM_BUILDER_THEME_ROOT . '/js/headroom.min.js', array( 'jquery' ), TM_BUILDER_PARENT_THEME_VERSION, true );
	}
	wp_enqueue_script( 'infinity-js-owl-carousel', TM_BUILDER_THEME_ROOT . '/js/owl.carousel.min.js', array( 'jquery' ), TM_BUILDER_PARENT_THEME_VERSION, true );
	wp_enqueue_script( 'infinity-js-main', TM_BUILDER_THEME_ROOT . '/js/main.js', array( 'jquery' ), TM_BUILDER_PARENT_THEME_VERSION, true );
	wp_enqueue_script( 'infinity-js-prettyphoto', TM_BUILDER_THEME_ROOT . '/js/jquery.prettyPhoto.js', array( 'jquery' ), TM_BUILDER_PARENT_THEME_VERSION, true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'infinity_scripts' );

/**
 * Setup custom css.
 * ================
 */
function infinity_custom_css() {
	$custom_css = Kirki::get_option( 'tm-builder', 'custom_css' );
	if ( Kirki::get_option( 'tm-builder', 'custom_css_enable' ) == 1 ) {
		wp_add_inline_style( 'infinity-main', $custom_css );
	}
}

add_action( 'wp_enqueue_scripts', 'infinity_custom_css' );

/**
 * Implement other setup.
 * ======================
 */
// Load core
require_once get_template_directory() . '/core/initial.php';
require_once get_template_directory() . '/inc/customizer/customizer.php';
require_once get_template_directory() . '/inc/oneclick.php';

// Load tmg
require_once get_template_directory() . '/inc/tgm-plugin-activation.php';
require_once get_template_directory() . '/inc/tgm-plugin-registration.php';

// Load metabox
require_once get_template_directory() . '/inc/meta-box.php';

// Load custom js
require_once get_template_directory() . '/inc/custom-js.php';

// Load custom header
require_once get_template_directory() . '/inc/custom-header.php';

// Custom template tags for this theme.
require_once get_template_directory() . '/inc/template-tags.php';

// Custom functions that act independently of the theme templates.
require_once get_template_directory() . '/inc/extras.php';

// Load Jetpack compatibility file.
require_once get_template_directory() . '/inc/jetpack.php';

// Support shortcode in widget
add_filter( 'widget_text', 'do_shortcode' );

// Remove admin notification of Projects
if ( class_exists( 'Projects_Admin' ) ) {
	global $projects;
	remove_action( 'admin_notices', array( $projects->admin, 'configuration_admin_notice' ) );
}

// Extend VC
if ( class_exists( 'WPBakeryVisualComposerAbstract' ) ) {
	function infinity_requireVcExtend() {
		require get_template_directory() . '/inc/vc-extend.php';
	}

	add_action( 'init', 'infinity_requireVcExtend', 2 );
}

/**
 * Woocommerce Setup
 * =================
 */
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );

// Switch to 3 columns
add_filter( 'loop_shop_columns', 'infinity_loop_columns', 999 );
if ( ! function_exists( 'infinity_loop_columns' ) ) {
	function infinity_loop_columns() {
		return 3; // 3 products per row
	}
}

// Three related products
add_filter( 'woocommerce_output_related_products_args', 'infinity_related_products_args' );
function infinity_related_products_args( $args ) {
	$args['posts_per_page'] = 3; // 3 related products
	$args['columns']        = 3; // arranged in 3 columns
	return $args;
}

function infinity_search_form( $form ) {
	$form = '<form method="get" class="search-form" action="' . home_url( '/' ) . '">
					<input type="search" class="search-field" placeholder="' . esc_attr__( 'Search...', 'tm-builder' ) . '" value="" name="s" title="' . esc_attr__( 'Search for:', 'tm-builder' ) . '">
				<input type="submit" class="search-submit" value="' . esc_attr__( 'Search', 'tm-builder' ) . '">
			</form>';

	return $form;
}

add_filter( 'get_search_form', 'infinity_search_form' );

if ( ! function_exists( 'infinity_base_encode' ) ) {
	function infinity_base_encode( $data ) {
		return $data;
	}
}

if ( ! function_exists( 'infinity_base_decode' ) ) {
	function infinity_base_decode( $data ) {
		return $data;
	}
}

if ( ! function_exists( 'is_tree' ) ) {
	function is_tree( $pid ) {
		global $post;
		if ( is_page() && ( $post->post_parent == $pid || is_page( $pid ) ) ) {
			return true;
		} else {
			return false;
		}
	}
}

//start admin bar & notice

add_action( 'admin_bar_menu', 'tm_builder_toolbar_links', 100 );
function tm_builder_toolbar_links( $wp_admin_bar ) {
	$wp_admin_bar->add_node( array(
		'id'    => 'tm_builder',
		'title' => '<span class="ab-icon"></span> ' . TM_BUILDER_PARENT_THEME_NAME . ' (v' . TM_BUILDER_PARENT_THEME_VERSION . ') ',
		'href'  => '#',
		'meta'  => array( 'class' => 'tm_builder_menu' )
	) );
	$wp_admin_bar->add_node( array(
		'id'     => 'tm_builder_customize',
		'parent' => 'tm_builder',
		'title'  => esc_html__( 'Customize', 'tm-builder' ),
		'href'   => admin_url( 'customize.php' )
	) );
	$wp_admin_bar->add_node( array(
		'id'     => 'tm_builder_support',
		'parent' => 'tm_builder',
		'title'  => esc_html__( 'Need Support?', 'tm-builder' ),
		'href'   => 'http://support.zooka.io',
		'meta'   => array( 'target' => '_blank' )
	) );
	$wp_admin_bar->remove_node( 'customize' );
	?>
	<style>
		.tm_builder_menu > a {
			background-color: #eb4723 !important;
			color: #ffffff !important
		}

		.tm_builder_menu > a:hover {
			background-color: #0073aa !important;
			color: #ffffff !important
		}

		.tm_builder_menu > a > .ab-icon:before {
			content: "\f540";
			top: 2px;
			color: #ffffff !important
		}

		.tm_notice {
			padding: 0px;
			margin: 40px 20px 20px 0;
			position: relative;
			overflow: hidden;
			display: block;
			border: 1px solid #e5e5e5;
			box-shadow: 0 1px 1px rgba(0, 0, 0, .04);
			background: #fff;
		}

		.tm_notice:before {
			content: '';
			width: 80px;
			height: 100%;
			background: #85B200;
			position: absolute;
			top: 0;
			left: 0;
			z-index: 998;
		}

		.tm_notice:after {
			content: "\f155";
			display: inline-block;
			width: 20px;
			height: 20px;
			font-size: 20px;
			line-height: 1;
			font-family: dashicons;
			position: absolute;
			top: 25px;
			left: 30px;
			color: #FFFFFF;
			z-index: 999;
		}

		.tm_notice_inner {
			padding: 10px 10px 10px 90px;
		}

		.tm_notice_hide {
			position: absolute;
			top: -1px;
			right: -1px;
			z-index: 999;
			display: none;
		}

		.tm_notice:hover .tm_notice_hide {
			display: block;
		}

		.tm_notice_hide input[type="submit"] {
			margin: 0;
			border-radius: 0;
			border: 1px solid #e5e5e5;
			outline: none;
			background: #ffffff;
			color: #777777;
			font-size: 13px;
			padding: 6px 10px;
			cursor: pointer;
		}

		.tm_notice_hide input[type="submit"]:hover {
			color: #ff6600;
		}
	</style>
	<?php
}

add_action( 'admin_notices', 'tm_builder_rate_notice' );
function tm_builder_rate_notice() {
	if ( isset( $_POST['tm_hide_rate'] ) && ( $_POST['tm_hide_rate'] == 1 ) ) {
		update_option( 'tm_hide_rate', '1' );
	}
	if ( get_option( 'tm_hide_rate', '0' ) != '1' ) {
		?>
		<div class="tm_notice">
			<div class="tm_notice_inner">
				Welcome onboard the
				<strong><?php echo TM_BUILDER_PARENT_THEME_NAME . ' (' . TM_BUILDER_PARENT_THEME_VERSION . ')'; ?></strong>.<br/>
				We are on the way to the “Great Website” island. Thank you for choosing to travel with us and we hope
				you
				enjoy your journey!<br/>
				If you are satisfied with
				<strong><?php echo TM_BUILDER_PARENT_THEME_NAME . ' (' . TM_BUILDER_PARENT_THEME_VERSION . ')'; ?></strong>,
				please reward it a <a
					href="http://www.awesomescreenshot.com/image/110934/c450eb8a46aaddb437bc234468168c74"
					target="_blank">full five-star ★★★★★ rating</a>. Thank you so much, Passengers!
				<div class="tm_notice_hide">
					<form action="" method="POST">
						<input type="hidden" name="tm_hide_rate" value="1"/>
						<input type="submit"
						       value="<?php _e( 'Hide this box', 'tm-builder' ); ?>"/>
					</form>
				</div>
			</div>
		</div>
		<?php
	}
}

add_action( 'admin_notices', 'tm_builder_admin_notice' );
function tm_builder_admin_notice() {
	if ( strpos( get_home_url(), 'localhost' ) === false ) {
	}
	if ( isset( $_POST['tm_allow_tracking'] ) ) {
		if ( $_POST['tm_allow_tracking'] == esc_html__( 'No', 'tm-builder' ) ) {
			update_option( 'tm_allow_tracking', '0' );
		} else {
			update_option( 'tm_allow_tracking', '1' );
		}
	}
	if ( get_option( 'tm_allow_tracking', '2' ) == '2' ) {
		?>
		<div class="updated">
			<p>
				<?php _e( 'You\'re using the theme', 'tm-builder' ); ?>
				<strong><?php echo TM_BUILDER_PARENT_THEME_NAME . ' (Version ' . TM_BUILDER_PARENT_THEME_VERSION . ')'; ?></strong>.
				<br/><?php _e( 'You want your website to get a better performance with TM Builder, don\'t you?<br/>If you say yes, we will collect your website URL then proactively monitor and contact you if we find any issue in your website.', 'tm-builder' ); ?>
			<form action="" method="POST">
				<input type="submit" name="tm_allow_tracking" class="button button-primary"
				       value="<?php _e( 'Yes, I accept', 'tm-builder' ); ?>"/>
				<input type="submit" name="tm_allow_tracking" class="button"
				       value="<?php _e( 'No', 'tm-builder' ); ?>"/>
			</form>
			</p>
		</div>
		<?php
	} else {
		if ( isset( $_POST['tm_allow_tracking'] ) ) {
			?>
			<div class="updated">
				<p><?php _e( 'Thanks for your choosed!', 'tm-builder' ); ?></p>
			</div>
			<?php if ( get_option( 'tm_allow_tracking', '2' ) == '1' ) {
				?>
				<script>
					jQuery(document).ready(function () {
						jQuery.get("http://builder.zooka.io?tracking=<?php echo urlencode( get_home_url() );?>");
					});
				</script>
				<?php
			}
			?>
			<?php
		}
	}
}

//end admin bar & notice

add_action( 'init', 'tm_builder_remove_vc_tgm_update_notice' );
function tm_builder_remove_vc_tgm_update_notice() {
	global $vc_manager;
	if ( ! empty( $vc_manager ) ) {
		$updater = $vc_manager->updater();
		remove_filter( 'upgrader_pre_download', array( $updater, 'preUpgradeFilter' ), 10 );
	}
}