<?php
/**
 * The Template for displaying all single projects.
 *
 * Override this template by copying it to yourtheme/projects/single-project.php
 *
 * @author        WooThemes
 * @package    Projects/Templates
 * @version     1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

$infinity_heading_image = Kirki::get_option( 'tm-builder', 'post_bg_image' );

get_header( 'projects' ); ?>
	<header class="big-title--single"
	        style="background-image: url('<?php echo esc_url( $infinity_heading_image ); ?>')">
		<div class="container">
			<?php the_title( '<h1 class="entry-title">', '</h1>' ); ?>
			<?php if ( function_exists( 'tm_bread_crumb' ) && Kirki::get_option( 'tm-builder', 'site_general_breadcrumb_enable' ) == 1 ) { ?>
				<div class="breadcrumb">
					<div class="container">
						<?php echo tm_bread_crumb( array( 'home_label' => esc_html__( 'Home', 'tm-builder' ) ) ); ?>
					</div>
				</div>
			<?php } ?>
		</div>
	</header>
	<div class="container">
		<?php while ( have_posts() ) : the_post(); ?>

			<?php do_action( 'projects_before_single_project' ); ?>

			<div class="row">
				<div class="col-md-8">
					<div class="gallery tm-gallery">
						<div class="tm-nav">
							<span class="tm-next"><i class="fa fa-angle-right"></i></span>
							<span class="tm-prev"><i class="fa fa-angle-left"></i></span>
						</div>
						<div class="project-slider">
							<?php
							$attachment_ids = projects_get_gallery_attachment_ids();
							$lightbox_rel   = apply_filters( 'projects_lightbox_rel', $rel = 'lightbox' );
							if ( $attachment_ids ) {
								?>
								<?php
								$loop    = 0;
								$columns = apply_filters( 'projects_project_gallery_columns', 3 );
								foreach ( $attachment_ids as $attachment_id ) {
									$classes = array( 'zoom' );
									if ( $loop == 0 || $loop % $columns == 0 ) {
										$classes[] = 'first';
									}
									if ( ( $loop + 1 ) % $columns == 0 ) {
										$classes[] = 'last';
									}
									$image_link = wp_get_attachment_url( $attachment_id );
									if ( ! $image_link ) {
										continue;
									}
									$image_class = esc_attr( implode( ' ', $classes ) );
									$image_title = esc_attr( get_the_title( $attachment_id ) );

									echo wp_get_attachment_image( $attachment_id, 'full' );

									$loop ++;
								} // endforeach
								?>
							<?php } // endif ?>
						</div>
					</div>
					<script>
						jQuery(document).ready(function () {
							owl = jQuery(".project-slider").owlCarousel({
								autoplay: true,
								autoplayTimeout: 3000,
								loop: true,
								items: 1,
								navigation: false,
								stopOnHover: true,
								paginationSpeed: 1000,
								goToFirstSpeed: 2000,
								singleItem: true,
								autoHeight: true,
								transitionStyle: "fade"
							});
							jQuery(".tm-prev").on('click', function () {
								owl.trigger('prev.owl.carousel');
							});

							jQuery(".tm-next").on('click', function () {
								owl.trigger('next.owl.carousel');
							});
						});
					</script>
				</div>
				<div class="col-md-4">
					<?php do_action( 'projects_single_project_summary' ); ?>
					<?php do_action( 'projects_after_single_project_summary' ); ?>
				</div>
			</div>

			<?php do_action( 'projects_after_single_project' ); ?>

		<?php endwhile; // end of the loop. ?>
	</div>
<?php get_footer( 'projects' );