<?php
/**
 * The Template for displaying all single projects.
 *
 * Override this template by copying it to yourtheme/projects/single-project.php
 *
 * @author        WooThemes
 * @package    Projects/Templates
 * @version     1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

$infinity_heading_image = Kirki::get_option( 'tm-builder', 'post_bg_image' );

get_header( 'projects' ); ?>
	<header class="big-title--single"
	        style="background-image: url('<?php echo esc_url( $infinity_heading_image ); ?>')">
		<div class="container">
			<?php the_title( '<h1 class="entry-title">', '</h1>' ); ?>
			<?php if ( function_exists( 'tm_bread_crumb' ) && Kirki::get_option( 'tm-builder', 'site_general_breadcrumb_enable' ) == 1 ) { ?>
				<div class="breadcrumb">
					<div class="container">
						<?php echo tm_bread_crumb( array( 'home_label' => esc_html__( 'Home', 'tm-builder' ) ) ); ?>
					</div>
				</div>
			<?php } ?>
		</div>
	</header>
	<div class="container">
		<?php while ( have_posts() ) : the_post(); ?>

			<?php do_action( 'projects_before_single_project' ); ?>
			<div class="row">
				<div class="single-project-description col-md-8">
					<h3 class="heading-title"><?php echo get_the_title(); ?></h3>
					<?php echo apply_filters( 'projects_description', the_content() ); ?>
				</div>
				<div class="project-meta col-md-4">
					<h3 class="heading-title">
						<?php echo esc_html__( 'Project Description', 'tm-builder' ); ?>
					</h3>
					<div class="project-meta__content">
						<?php
						// Categories
						$terms_as_text = get_the_term_list( $post->ID, 'project-category', '<li>', ',</li><li>', '</li>' );
						// Meta
						$client         = esc_attr( get_post_meta( $post->ID, '_client', true ) );
						$url            = esc_url( get_post_meta( $post->ID, '_url', true ) );
						$location       = esc_attr( get_post_meta( $post->ID, '_location', true ) );
						$surface_area   = esc_attr( get_post_meta( $post->ID, '_surface_area', true ) );
						$year_completed = esc_attr( get_post_meta( $post->ID, '_year_completed', true ) );
						$value          = esc_attr( get_post_meta( $post->ID, '_value', true ) );
						$architect      = esc_attr( get_post_meta( $post->ID, '_architect', true ) );
						do_action( 'projects_before_meta' );
						if ( $client ) {
							echo '<div class="client">';
							echo '<span class="client__title meta-title">' . esc_html__( 'Client', 'tm-builder' ) . ': </span>';
							echo '<span class="client__name meta-value">' . $client . '</span>';
							echo '</div>';
						}
						if ( $location ) {
							echo '<div class="location">';
							echo '<span class="location__title meta-title">' . esc_html__( 'Location', 'tm-builder' ) . ': </span>';
							echo '<span class="location__name meta-value">' . $location . '</span>';
							echo '</div>';
						}
						if ( $surface_area ) {
							echo '<div class="surface-area">';
							echo '<span class="surface-area__title meta-title">' . esc_html__( 'Surface Area', 'tm-builder' ) . ': </span>';
							echo '<span class="surface-area__name meta-value">' . $surface_area . '</span>';
							echo '</div>';
						}
						if ( $year_completed ) {
							echo '<div class="year-complete">';
							echo '<span class="year-complete__title meta-title">' . esc_html__( 'Year Completed', 'tm-builder' ) . ': </span>';
							echo '<span class="year-complete__name meta-value">' . $year_completed . '</span>';
							echo '</div>';
						}
						if ( $value ) {
							echo '<div class="architect">';
							echo '<span class="architect__title meta-title">' . esc_html__( 'Value', 'tm-builder' ) . ': </span>';
							echo '<span class="architect__name meta-value">' . $value . '</span>';
							echo '</div>';
						}
						if ( $architect ) {
							echo '<div class="architect">';
							echo '<span class="architect__title meta-title">' . esc_html__( 'Architect', 'tm-builder' ) . ': </span>';
							echo '<span class="architect__name meta-value">' . $architect . '</span>';
							echo '</div>';
						}
						if ( $url ) {
							echo '<div class="url">';
							echo '<span class="architect__title meta-title">' . esc_html__( 'Link', 'tm-builder' ) . ': </span>';
							echo '<span class="project-url"><a href="' . esc_attr( $url ) . '">' . apply_filters( 'projects_visit_project_link', esc_html__( 'Visit project', 'tm-builder' ) ) . '</a></span>';
							echo '</div>';
						}
						do_action( 'projects_after_meta' );
						?>
					</div>
				</div>
				<?php do_action( 'projects_after_single_project_summary' ); ?>
			</div>
			<div class="row project-gallery">
				<?php
				$attachment_ids = projects_get_gallery_attachment_ids();
				$lightbox_rel   = apply_filters( 'projects_lightbox_rel', $rel = 'lightbox' );
				if ( $attachment_ids ) {
					?>
					<?php
					$loop    = 0;
					$columns = apply_filters( 'projects_project_gallery_columns', 3 );
					foreach ( $attachment_ids as $attachment_id ) {
						$classes = array( 'zoom' );
						if ( $loop == 0 || $loop % $columns == 0 ) {
							$classes[] = 'first';
						}
						if ( ( $loop + 1 ) % $columns == 0 ) {
							$classes[] = 'last';
						}
						$image_link = wp_get_attachment_url( $attachment_id );
						if ( ! $image_link ) {
							continue;
						}
						$image_class = esc_attr( implode( ' ', $classes ) );
						$image_title = esc_attr( get_the_title( $attachment_id ) );
						if ( apply_filters( 'projects_gallery_link_images', true ) ) {
							echo '<div class="col-md-4"><a href="' . esc_url( $image_link ) . '" title="' . esc_attr( $image_title ) . '" rel="prettyPhoto[infinity]">' . wp_get_attachment_image( $attachment_id, array(
									770,
									513
								) ) . '</a></div>';
						} else {
							echo '<div class="col-md-4">' . wp_get_attachment_image( $attachment_id, array(
									770,
									513
								) ) . '</div>';
						}
						$loop ++;
					} // endforeach
					?>
					<script type="text/javascript">
						jQuery(document).ready(function () {
							jQuery("a[rel^='prettyPhoto']").prettyPhoto();
						});
					</script>
				<?php } // endif ?>
			</div>

			<?php do_action( 'projects_after_single_project' ); ?>

		<?php endwhile; // end of the loop. ?>
	</div>
<?php get_footer( 'projects' );