<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive.
 *
 * Override this template by copying it to yourtheme/woocommerce/archive-product.php
 *
 * @author        WooThemes
 * @package    WooCommerce/Templates
 * @version     2.6.4
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}
$infinity_woo_layout_category = Kirki::get_option( 'tm-builder', 'woo_layout_category' );
$infinity_page_layout_private = get_post_meta( get_the_ID(), "infinity_page_layout_private", true );
$infinity_header_top          = get_post_meta( get_the_ID(), "infinity_header_top", true );
$infinity_sticky_menu         = get_post_meta( get_the_ID(), "infinity_sticky_menu", true );
$infinity_custom_logo         = get_post_meta( get_the_ID(), "infinity_custom_logo", true );
$infinity_heading_image       = get_post_meta( get_the_ID(), "infinity_heading_image", true );
$infinity_bread_crumb_enable  = get_post_meta( get_the_ID(), "infinity_bread_crumb_enable", true );
$infinity_disable_comment     = get_post_meta( get_the_ID(), "infinity_disable_comment", true );
$infinity_disable_title       = get_post_meta( get_the_ID(), "infinity_disable_title", true );
$infinity_custom_class        = get_post_meta( get_the_ID(), "infinity_custom_class", true );
if ( $infinity_heading_image ) {
	$infinity_heading_image = get_post_meta( get_the_ID(), "infinity_heading_image", true );
} else {
	$infinity_heading_image = Kirki::get_option( 'tm-builder', 'page_bg_image' );
}
get_header(); ?>
<?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
	<div class="big-title" style="background-image: url('<?php echo esc_url( $infinity_heading_image ); ?>')">
		<div class="container">
			<h1 class="entry-title">
				<?php woocommerce_page_title(); ?>
			</h1>
			<?php if ( function_exists( 'tm_bread_crumb' ) ) { ?>
				<div class="breadcrumb">
					<div class="container">
						<?php echo tm_bread_crumb( array( 'home_label' => esc_html__( 'Home', 'tm-builder' ) ) ); ?>
					</div>
				</div>
			<?php } ?>
		</div>
	</div>
<?php endif; ?>
<div class="container">
	<?php if ( is_active_sidebar( 'top-shop' ) ) { ?>
		<div class="top-shop hidden-sm hidden-xs" id="top-shop">
			<?php dynamic_sidebar( 'top-shop' ); ?>
		</div>
	<?php } ?>
	<div class="row">
		<?php if ( $infinity_woo_layout_category == 'sidebar-content' ) { ?>
			<?php do_action( 'woocommerce_sidebar' ); ?>
		<?php } ?>
		<?php if ( $infinity_woo_layout_category == 'sidebar-content' || $infinity_woo_layout_category == 'content-sidebar' ) { ?>
			<?php $class = 'col-md-8'; ?>
		<?php } else { ?>
			<?php $class = 'col-md-12'; ?>
		<?php } ?>
		<div class="<?php echo esc_attr( $class ); ?>">
			<?php do_action( 'woocommerce_before_main_content' ); ?>

			<?php do_action( 'woocommerce_archive_description' ); ?>

			<?php if ( have_posts() ) : ?>

				<div class="row middle">
					<?php do_action( 'woocommerce_before_shop_loop' ); ?>
				</div>

				<div class="row">
					<?php woocommerce_product_subcategories(); ?>
				</div>

				<?php woocommerce_product_loop_start(); ?>

				<?php while ( have_posts() ) : the_post(); ?>

					<?php wc_get_template_part( 'content', 'product' ); ?>

				<?php endwhile; // end of the loop. ?>

				<?php woocommerce_product_loop_end(); ?>

				<?php do_action( 'woocommerce_after_shop_loop' ); ?>

				<?php
			elseif ( ! woocommerce_product_subcategories( array(
				'before' => woocommerce_product_loop_start( false ),
				'after'  => woocommerce_product_loop_end( false )
			) )
			) : ?>

				<?php wc_get_template( 'loop/no-products-found.php' ); ?>

			<?php endif; ?>

			<?php do_action( 'woocommerce_after_main_content' ); ?>
		</div>
		<?php if ( $infinity_woo_layout_category == 'content-sidebar' ) { ?>
			<?php do_action( 'woocommerce_sidebar' ); ?>
		<?php } ?>
	</div>
</div>

<?php get_footer( 'shop' ); ?>
